@@ -21,7 +21,7 @@ package Clownfish::Build;
 my $IS_CPAN_DIST;
 
 BEGIN {
-    $IS_CPAN_DIST = -e 'core';
+    $IS_CPAN_DIST = -e 'cfcore';
 
     if (!$IS_CPAN_DIST) {
         unshift @INC,
@@ -36,7 +36,7 @@ use base qw(
     Clownfish::CFC::Perl::Build::Charmonic
 );
 
-our $VERSION = '0.005001';
+our $VERSION = '0.006000';
 $VERSION = eval $VERSION;
 
 use File::Spec::Functions qw( catdir catfile updir rel2abs );
@@ -49,17 +49,22 @@ use Cwd qw( getcwd );
 my @BASE_PATH = __PACKAGE__->cf_base_path;
 
 my $COMMON_SOURCE_DIR = catdir( @BASE_PATH, 'common' );
-my $CORE_SOURCE_DIR   = catdir( @BASE_PATH, 'core' );
 my $CFC_DIR           = catdir( @BASE_PATH, updir(), 'compiler', 'perl' );
 my $XS_SOURCE_DIR = 'xs';
 my $CFC_BUILD     = catfile( $CFC_DIR, 'Build' );
 my $LIB_DIR       = 'lib';
+my $CORE_SOURCE_DIR;
+my $TEST_SOURCE_DIR;
 my $CHARMONIZER_C;
 if ($IS_CPAN_DIST) {
-    $CHARMONIZER_C = 'charmonizer.c';
+    $CORE_SOURCE_DIR = 'cfcore';
+    $TEST_SOURCE_DIR = 'cftest';
+    $CHARMONIZER_C   = 'charmonizer.c';
 }
 else {
-    $CHARMONIZER_C = catfile( $COMMON_SOURCE_DIR, 'charmonizer.c' );
+    $CORE_SOURCE_DIR = catdir( @BASE_PATH, 'core' );
+    $TEST_SOURCE_DIR = catdir( @BASE_PATH, 'test' );
+    $CHARMONIZER_C   = catfile( $COMMON_SOURCE_DIR, 'charmonizer.c' );
 }
 
 sub new {
@@ -68,7 +73,20 @@ sub new {
     $args{clownfish_params} = {
         autogen_header => _autogen_header(),
         include        => [],                  # Don't use default includes.
-        source => [ $CORE_SOURCE_DIR, $XS_SOURCE_DIR ],
+        source         => [ $CORE_SOURCE_DIR, $TEST_SOURCE_DIR ],
+        modules => [
+            {
+                name          => 'Clownfish',
+                parcels       => [ 'Clownfish' ],
+                make_target   => 'core_objects',
+                c_source_dirs => [ $XS_SOURCE_DIR ],
+            },
+            {
+                name          => 'Clownfish::Test',
+                parcels       => [ 'TestClownfish' ],
+                make_target   => 'test_objects',
+            },
+        ],
     };
     my $self = $class->SUPER::new( recursive_test_files => 1, %args );
 
@@ -83,12 +101,7 @@ sub new {
         $self->extra_compiler_flags(@$extra_cflags);
     }
 
-    if ( $ENV{LUCY_VALGRIND} ) {
-        my $optimize = $self->config('optimize') || '';
-        $optimize =~ s/\-O\d+/-O1/g;
-        $self->config( optimize => $optimize );
-    }
-
+    $self->charmonizer_params( create_makefile => 1 );
     $self->charmonizer_params( charmonizer_c => $CHARMONIZER_C );
 
     return $self;
@@ -126,10 +139,10 @@ sub ACTION_cfc {
     chdir($old_dir);
 }
 
-sub ACTION_copy_clownfish_includes {
+sub ACTION_code {
     my $self = shift;
 
-    $self->SUPER::ACTION_copy_clownfish_includes;
+    $self->SUPER::ACTION_code;
 
     $self->cf_copy_include_file( 'XSBind.h' );
 }
@@ -140,6 +153,9 @@ sub ACTION_clownfish {
     $self->depends_on('cfc');
 
     $self->SUPER::ACTION_clownfish;
+
+    # Make sure to remove empty directory.
+    $self->add_to_cleanup( catdir( $LIB_DIR, 'Clownfish', 'Docs' ) );
 }
 
 sub ACTION_compile_custom_xs {
@@ -173,7 +189,7 @@ sub ACTION_compile_custom_xs {
 
 sub _valgrind_base_command {
     return
-          "PERL_DESTRUCT_LEVEL=2 LUCY_VALGRIND=1 valgrind "
+          "PERL_DESTRUCT_LEVEL=2 CLOWNFISH_VALGRIND=1 valgrind "
         . "--leak-check=yes "
         . "--show-reachable=yes "
         . "--dsymutil=yes "
@@ -182,8 +198,7 @@ sub _valgrind_base_command {
 
 # Run the entire test suite under Valgrind.
 #
-# For this to work, Lucy must be compiled with the LUCY_VALGRIND environment
-# variable set to a true value, under a debugging Perl.
+# For this to work, the test suite must be run under a debugging Perl.
 #
 # A custom suppressions file will probably be needed -- use your judgment.
 # To pass in one or more local suppressions files, provide a comma separated
@@ -197,9 +212,6 @@ sub ACTION_test_valgrind {
     die "Must be run under a perl that was compiled with -DDEBUGGING"
         unless $self->config('ccflags') =~ /-D?DEBUGGING\b/
                || $^X =~ /\bdebugperl\b/;
-    if ( !$ENV{LUCY_VALGRIND} ) {
-        warn "\$ENV{LUCY_VALGRIND} not true -- possible false positives";
-    }
     $self->depends_on('code');
 
     # Unbuffer STDOUT, grab test file names and suppressions files.
@@ -307,11 +319,13 @@ sub ACTION_dist {
     # the top-level $REPOS_ROOT.  Because some assets we need are outside this
     # directory, we need to copy them in.
     my %to_copy = (
+        '../../CHANGES'         => 'CHANGES',
         '../../CONTRIBUTING.md' => 'CONTRIBUTING.md',
         '../../LICENSE'         => 'LICENSE',
         '../../NOTICE'          => 'NOTICE',
         '../../README.md'       => 'README.md',
-        $CORE_SOURCE_DIR        => 'core',
+        $CORE_SOURCE_DIR        => 'cfcore',
+        $TEST_SOURCE_DIR        => 'cftest',
         $CHARMONIZER_C          => 'charmonizer.c',
     );
     print "Copying files...\n";
