@@ -16,7 +16,7 @@ package Clownfish::Build::Binding;
 use strict;
 use warnings;
 
-our $VERSION = '0.005001';
+our $VERSION = '0.006000';
 $VERSION = eval $VERSION;
 
 sub bind_all {
@@ -38,7 +38,6 @@ sub bind_all {
     $class->bind_obj;
     $class->bind_vector;
     $class->bind_class;
-    $class->bind_stringhelper;
 }
 
 sub bind_clownfish {
@@ -67,18 +66,13 @@ END_XS_CODE
 
 sub bind_test {
     my $xs_code = <<'END_XS_CODE';
-MODULE = Clownfish   PACKAGE = Clownfish::Test
+MODULE = Clownfish::Test   PACKAGE = Clownfish::Test
 
-bool
-run_tests(class_name)
-    cfish_String *class_name;
+SV*
+create_test_suite()
 CODE:
-    cfish_TestFormatter *formatter
-        = (cfish_TestFormatter*)cfish_TestFormatterTAP_new();
     cfish_TestSuite *suite = testcfish_Test_create_test_suite();
-    RETVAL = CFISH_TestSuite_Run_Batch(suite, class_name, formatter);
-    CFISH_DECREF(formatter);
-    CFISH_DECREF(suite);
+    RETVAL = CFISH_OBJ_TO_SV_NOINC(suite);
 OUTPUT: RETVAL
 
 void
@@ -107,7 +101,6 @@ END_XS_CODE
 
 sub bind_test_host {
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "TestClownfish",
         class_name => "Clownfish::Test::TestHost",
     );
     $binding->bind_method(
@@ -153,7 +146,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Blob",
     );
     $binding->set_pod_spec($pod_spec);
@@ -207,7 +199,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Boolean",
     );
     $binding->set_pod_spec($pod_spec);
@@ -252,7 +243,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::ByteBuf",
     );
     $binding->set_pod_spec($pod_spec);
@@ -274,7 +264,6 @@ END_SYNOPSIS
     $pod_spec->add_constructor();
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::CharBuf",
     );
     $binding->set_pod_spec($pod_spec);
@@ -317,7 +306,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::String",
     );
     $binding->set_pod_spec($pod_spec);
@@ -415,7 +403,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::StringIterator",
     );
     $binding->set_pod_spec($pod_spec);
@@ -464,7 +451,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Err",
     );
     $binding->bind_constructor( alias => '_new' );
@@ -507,7 +493,7 @@ fetch_raw(self, key)
     cfish_Hash *self;
     cfish_String *key;
 CODE:
-    RETVAL = CFISH_OBJ_TO_SV_INC(CFISH_Hash_Fetch_IMP(self, key));
+    RETVAL = CFISH_OBJ_TO_SV_INC(CFISH_Hash_Fetch(self, key));
 OUTPUT: RETVAL
 
 void
@@ -519,12 +505,11 @@ PPCODE:
 {
     cfish_Obj *value
         = (cfish_Obj*)XSBind_perl_to_cfish_nullable(aTHX_ value_sv, CFISH_OBJ);
-    CFISH_Hash_Store_IMP(self, key, value);
+    CFISH_Hash_Store(self, key, value);
 }
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Hash",
     );
     $binding->set_pod_spec($pod_spec);
@@ -567,7 +552,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::HashIterator",
     );
     $binding->set_pod_spec($pod_spec);
@@ -607,7 +591,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Float",
     );
     $binding->set_pod_spec($pod_spec);
@@ -647,7 +630,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Integer",
     );
     $binding->set_pod_spec($pod_spec);
@@ -751,7 +733,6 @@ END_POD
     $pod_spec->set_synopsis($synopsis);
     $pod_spec->set_description($description);
     $pod_spec->add_method(
-        method => 'To_Host',
         alias  => 'to_perl',
         pod    => $to_perl_pod,
     );
@@ -769,7 +750,7 @@ get_class(self)
     cfish_Obj *self
 CODE:
     cfish_Class *klass = cfish_Obj_get_class(self);
-    RETVAL = (SV*)CFISH_Class_To_Host(klass);
+    RETVAL = (SV*)CFISH_Class_To_Host(klass, NULL);
 OUTPUT: RETVAL
 
 SV*
@@ -777,7 +758,7 @@ get_class_name(self)
     cfish_Obj *self
 CODE:
     cfish_String *class_name = cfish_Obj_get_class_name(self);
-    RETVAL = (SV*)CFISH_Str_To_Host(class_name);
+    RETVAL = (SV*)CFISH_Str_To_Host(class_name, NULL);
 OUTPUT: RETVAL
 
 bool
@@ -802,12 +783,11 @@ SV*
 to_perl(self)
     cfish_Obj *self;
 CODE:
-    RETVAL = (SV*)CFISH_Obj_To_Host(self);
+    RETVAL = (SV*)CFISH_Obj_To_Host(self, NULL);
 OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Obj",
     );
     $binding->bind_method(
@@ -872,7 +852,7 @@ store(self, tick, value);
 PPCODE:
 {
     if (value) { CFISH_INCREF(value); }
-    CFISH_Vec_Store_IMP(self, tick, value);
+    CFISH_Vec_Store(self, tick, value);
 }
 
 SV*
@@ -885,7 +865,6 @@ OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Vector",
     );
     $binding->set_pod_spec($pod_spec);
@@ -922,7 +901,7 @@ CODE:
 {
     cfish_Class *klass = cfish_Class_fetch_class(class_name);
     CFISH_UNUSED_VAR(unused_sv);
-    RETVAL = klass ? (SV*)CFISH_Class_To_Host(klass) : &PL_sv_undef;
+    RETVAL = klass ? (SV*)CFISH_Class_To_Host(klass, NULL) : &PL_sv_undef;
 }
 OUTPUT: RETVAL
 
@@ -949,13 +928,12 @@ CODE:
                 aTHX_ ST(locations[1]), "parent", CFISH_CLASS, NULL);
     }
     singleton = cfish_Class_singleton(class_name, parent);
-    RETVAL = (SV*)CFISH_Class_To_Host(singleton);
+    RETVAL = (SV*)CFISH_Class_To_Host(singleton, NULL);
 }
 OUTPUT: RETVAL
 END_XS_CODE
 
     my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
         class_name => "Clownfish::Class",
     );
     $binding->set_pod_spec($pod_spec);
@@ -964,105 +942,4 @@ END_XS_CODE
     Clownfish::CFC::Binding::Perl::Class->register($binding);
 }
 
-sub bind_stringhelper {
-    my $xs_code = <<'END_XS_CODE';
-MODULE = Clownfish   PACKAGE = Clownfish::Util::StringHelper
-
-=for comment
-
-Turn an SV's UTF8 flag on.  Equivalent to Encode::_utf8_on, but we don't have
-to load Encode.
-
-=cut
-
-void
-utf8_flag_on(sv)
-    SV *sv;
-PPCODE:
-    SvUTF8_on(sv);
-
-=for comment
-
-Turn an SV's UTF8 flag off.
-
-=cut
-
-void
-utf8_flag_off(sv)
-    SV *sv;
-PPCODE:
-    SvUTF8_off(sv);
-
-SV*
-to_base36(num)
-    uint64_t num;
-CODE:
-{
-    char base36[cfish_StrHelp_MAX_BASE36_BYTES];
-    size_t size = cfish_StrHelp_to_base36(num, &base36);
-    RETVAL = newSVpvn(base36, size);
-}
-OUTPUT: RETVAL
-
-IV
-from_base36(str)
-    char *str;
-CODE:
-    RETVAL = strtol(str, NULL, 36);
-OUTPUT: RETVAL
-
-=for comment
-
-Upgrade a SV to UTF8, converting Latin1 if necessary. Equivalent to
-utf::upgrade().
-
-=cut
-
-void
-utf8ify(sv)
-    SV *sv;
-PPCODE:
-    sv_utf8_upgrade(sv);
-
-bool
-utf8_valid(sv)
-    SV *sv;
-CODE:
-{
-    STRLEN len;
-    char *ptr = SvPV(sv, len);
-    RETVAL = cfish_StrHelp_utf8_valid(ptr, len);
-}
-OUTPUT: RETVAL
-
-=for comment
-
-Concatenate one scalar onto the end of the other, ignoring UTF-8 status of the
-second scalar.  This is necessary because $not_utf8 . $utf8 results in a
-scalar which has been infected by the UTF-8 flag of the second argument.
-
-=cut
-
-void
-cat_bytes(sv, catted)
-    SV *sv;
-    SV *catted;
-PPCODE:
-{
-    STRLEN len;
-    char *ptr = SvPV(catted, len);
-    if (SvUTF8(sv)) { CFISH_THROW(CFISH_ERR, "Can't cat_bytes onto a UTF-8 SV"); }
-    sv_catpvn(sv, ptr, len);
-}
-END_XS_CODE
-
-    my $binding = Clownfish::CFC::Binding::Perl::Class->new(
-        parcel     => "Clownfish",
-        class_name => "Clownfish::Util::StringHelper",
-    );
-    $binding->append_xs($xs_code);
-
-    Clownfish::CFC::Binding::Perl::Class->register($binding);
-}
-
 1;
