@@ -20,9 +20,9 @@ package Clownfish;
 
 use 5.008003;
 
-our $VERSION = '0.005001';
+our $VERSION = '0.006000';
 $VERSION = eval $VERSION;
-our $MAJOR_VERSION = 0.005000;
+our $MAJOR_VERSION = 0.006000;
 
 use Exporter 'import';
 BEGIN {
@@ -38,32 +38,14 @@ BEGIN {
     require DynaLoader;
     our @ISA = qw( DynaLoader );
     # This loads a large number of disparate subs.
-    bootstrap Clownfish '0.5.1';
+    bootstrap Clownfish '0.6.0';
 }
 
 sub error {$Clownfish::Err::error}
 
-{
-    package Clownfish::Util::StringHelper;
-    our $VERSION = '0.005001';
-    $VERSION = eval $VERSION;
-    BEGIN {
-        push our @ISA, 'Exporter';
-        our @EXPORT_OK = qw(
-            utf8_flag_on
-            utf8_flag_off
-            to_base36
-            from_base36
-            utf8ify
-            utf8_valid
-            cat_bytes
-        );
-    }
-}
-
 {
     package Clownfish::Obj;
-    our $VERSION = '0.005001';
+    our $VERSION = '0.006000';
     $VERSION = eval $VERSION;
     use Carp qw( confess );
     # Clownfish objects are not thread-safe.
@@ -80,7 +62,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Class;
-    our $VERSION = '0.005001';
+    our $VERSION = '0.006000';
     $VERSION = eval $VERSION;
 
     sub _find_parent_class {
@@ -123,7 +105,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Method;
-    our $VERSION = '0.005001';
+    our $VERSION = '0.006000';
     $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub CLONE_SKIP { 0; }
@@ -132,7 +114,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Err;
-    our $VERSION = '0.005001';
+    our $VERSION = '0.006000';
     $VERSION = eval $VERSION;
     sub do_to_string { shift->to_string }
     use Scalar::Util qw( blessed );
@@ -171,7 +153,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Boolean;
-    our $VERSION = '0.005001';
+    our $VERSION = '0.006000';
     $VERSION = eval $VERSION;
     use Exporter 'import';
     our @EXPORT_OK = qw( $true_singleton $false_singleton );
