@@ -15,9 +15,28 @@
 
 package Clownfish::Test;
 use Clownfish;
-our $VERSION = '0.005001';
+our $VERSION = '0.006000';
 $VERSION = eval $VERSION;
 
+sub dl_load_flags { 1 }
+
+BEGIN {
+    require DynaLoader;
+    our @ISA = qw( DynaLoader );
+    bootstrap Clownfish::Test '0.6.0';
+}
+
+sub run_tests {
+    my $class_name = shift;
+    my $formatter  = Clownfish::TestHarness::TestFormatterTAP->new();
+    my $suite      = Clownfish::Test::create_test_suite();
+
+    return $suite->run_batch(
+        class_name => $class_name,
+        formatter  => $formatter,
+    );
+}
+
 1;
 
 __END__
